;; Generated package description from avy.el  -*- no-byte-compile: t -*-
(define-package "avy" "0.5.0.0.20241101.125753" "Jump to arbitrary positions in visible text and select text quickly." '((emacs "24.1") (cl-lib "0.5")) :commit "4ac1d17a0740a075341a56380bbb0c1a441accf1" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Oleh Krehel" . "ohwoeowho@gmail.com") :keywords '("point" "location") :url "https://github.com/abo-abo/avy")
